Available on crate feature
smallvec only.Structs
- Drain
- An iterator that removes the items from a
SmallVecand yields them by value. - Extract
If - An iterator that removes elements matching a predicate from a range.
- Into
Iter - An iterator that consumes a
SmallVecand yields its items by value. - Small
Vec - A vector with inline storage that spills to heap when capacity is exceeded.